==> db-0.3.15.jar: db/burningswell-db/migrations/revert/switch-to-geography.sql <==
-- Revert switch-to-geography

BEGIN;

ALTER TABLE "time-zones" ALTER COLUMN geom TYPE geometry(MULTIPOLYGON, 4326) USING geometry(ST_SetSRID(geography(geom), 4326));
ALTER TABLE airports ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE continents ALTER COLUMN geom TYPE geometry(MULTIPOLYGON, 4326) USING geometry(ST_SetSRID(geography(geom), 4326));
ALTER TABLE continents ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE countries ALTER COLUMN geom TYPE geometry(MULTIPOLYGON, 4326) USING geometry(ST_SetSRID(geography(geom), 4326));
ALTER TABLE countries ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE photos ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE ports ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE regions ALTER COLUMN geom TYPE geometry(MULTIPOLYGON, 4326) USING geometry(ST_SetSRID(geography(geom), 4326));
ALTER TABLE regions ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE spots ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE users ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));

COMMIT;

==> db-0.3.29.jar: db/burningswell-db/migrations/revert/switch-to-geography.sql <==
-- Revert switch_to_geography

BEGIN;

ALTER TABLE "time_zones" ALTER COLUMN geom TYPE geometry(MULTIPOLYGON, 4326) USING geometry(ST_SetSRID(geography(geom), 4326));
ALTER TABLE airports ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE continents ALTER COLUMN geom TYPE geometry(MULTIPOLYGON, 4326) USING geometry(ST_SetSRID(geography(geom), 4326));
ALTER TABLE continents ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE countries ALTER COLUMN geom TYPE geometry(MULTIPOLYGON, 4326) USING geometry(ST_SetSRID(geography(geom), 4326));
ALTER TABLE countries ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE photos ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE ports ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE regions ALTER COLUMN geom TYPE geometry(MULTIPOLYGON, 4326) USING geometry(ST_SetSRID(geography(geom), 4326));
ALTER TABLE regions ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE spots ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));
ALTER TABLE users ALTER COLUMN location TYPE geometry(POINT, 4326) USING geometry(ST_SetSRID(geography(location), 4326));

COMMIT;
